@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use ExtUtils::Manifest qw( maniread );
 
-our $VERSION = '0.13';
+our $VERSION = '0.15';
 
 use Exporter;
 
@@ -49,11 +49,7 @@ READ:
 }
 
 sub _planned {
-  if ($Test::More::VERSION >= 2) {
-    Test::More->builder->_plan_handled;
-  } else {
-    Test::More->builder->{Have_Plan};
-  }
+  Test::More->builder->has_plan;
 }
 
 sub all_uses_ok {
